/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "MainWindow.h"

// Qt includes
#include <QApplication>
#include <QCoreApplication>
#include <QStringList>
#include <QDebug>
#include <QTranslator>
#include <QLibraryInfo>

namespace {
const QString STYLE = QString::fromUtf8("QGroupBox { font-weight: bold; } "
                                        "QScrollArea { background-color: transparent; } ");
}

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QTranslator qtTranslator;

    bool loadedExternalTranslations;
    bool loadedResourceTranslations;
    loadedExternalTranslations = qtTranslator.load(
        QString::fromUtf8("qt_") + QLocale::system().name(),
        QLibraryInfo::location(QLibraryInfo::TranslationsPath)
    );
    if (! loadedExternalTranslations) {
        loadedResourceTranslations = qtTranslator.load(
            QString::fromUtf8("qt_") + QLocale::system().name(), QString::fromUtf8(":/"));
    }

    if (loadedExternalTranslations || loadedResourceTranslations) {
        app.installTranslator(&qtTranslator);
    }

    app.setStyleSheet(STYLE);

    MainWindow mainWindow;
    mainWindow.show();

    QStringList arguments = QCoreApplication::arguments();
    if (arguments.count() > 1) {
        mainWindow.loadTournament(arguments[1]);
    }

    return app.exec();
}
