/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "MainWindow.h"
#include "AboutWindow.h"
#include "Database.h"
#include "version.h"

// Qt includes
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QGroupBox>
#include <QLabel>
#include <QPushButton>
#include <QDebug>
#include <QDialogButtonBox>

AboutWindow::AboutWindow(QWidget *parent, Database *db)
    : QDialog(parent), m_db(db)
{
    setAttribute(Qt::WA_DeleteOnClose);

    setWindowTitle(tr("Über Muckturnier"));
    QVBoxLayout *layout = new QVBoxLayout(this);

    // icon, version

    QGroupBox *headerBox = new QGroupBox;
    QHBoxLayout *headerBoxLayout = new QHBoxLayout(headerBox);
    layout->addWidget(headerBox);

    QLabel *iconLabel = new QLabel;
    iconLabel->setPixmap(QIcon(
            dynamic_cast<MainWindow *>(parent)->resourcePath(QString::fromUtf8("muckturnier.svg"))
        ).pixmap(QSize(64, 64)));
    iconLabel->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
    headerBoxLayout->addWidget(iconLabel);

    QLabel *headerLabel = new QLabel(
        QString::fromUtf8("<h2>Muckturnier</h2>")
        + QString::fromUtf8("<p><b>")
        + tr("Version %1").arg(QString::fromUtf8(MT_VERSION))
        + QString::fromUtf8("</b><br/>")
        + tr("Datenbankrevision %1").arg(m_db->getDbVersion()) + QString::fromUtf8("<br/>")
        + tr("Kompiliert gegen")
        + QString::fromUtf8(" <a href=\"http://www.qt.io/\">Qt</a> %1</p>").arg(
                            QString::fromUtf8(QT_VERSION_STR))
    );
    headerLabel->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    headerLabel->setOpenExternalLinks(true);
    headerBoxLayout->addWidget(headerLabel);

    // info

    QGroupBox *infoBox = new QGroupBox;
    QVBoxLayout *infoBoxLayout = new QVBoxLayout(infoBox);
    layout->addWidget(infoBox);

    QLabel *infoLabel = new QLabel(
        QString::fromUtf8("<p>")
        + tr("Ein Programm zum Auswerten von Muckturnieren") + QString::fromUtf8("</p><p>")
        + QString::fromUtf8("Copyright © 2012–%1<br/>Tobias Leupold "
                            "&lt;<a href=\"mailto:tobias.leupold@gmx.de\">"
                            "tobias.leupold@gmx.de"
                            "</a>&gt;").arg(QString::fromUtf8(__DATE__).right(4))
        + QString::fromUtf8("</p><p>")
        + tr("Homepage:")
        + QString::fromUtf8(" <a href=\"http://nasauber.de/opensource/muckturnier/\">"
                            "http://nasauber.de/opensource/muckturnier/</a><br/>")
        + tr("Lizenz:")
        + QString::fromUtf8(" <a href=\"http://www.gnu.org/licenses/\">GNU GPL v2</a></p>")
    );

    infoLabel->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    infoLabel->setOpenExternalLinks(true);
    infoBoxLayout->addWidget(infoLabel);

    // close button
    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
    connect(buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &QDialog::accept);
    layout->addWidget(buttonBox);
}
