/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef EXPORTDIALOG_H
#define EXPORTDIALOG_H

// Qt includes
#include <QDialog>

// Qt classes
class QLineEdit;
class QPushButton;
class QCheckBox;
class QGroupBox;
class QColor;
class QRadioButton;
class QLabel;
class QTextStream;
class QDialogButtonBox;

// Local classes
class Database;
class RankingPage;

class ExportDialog : public QDialog
{
    Q_OBJECT

public:
    explicit ExportDialog(QWidget *parent, Database *db, RankingPage *rankingPage);

signals:
    void statusUpdate(QString message);

private: // Functions
    void accept();
    void saveHTMLFile(QTextStream &outStream);
    void saveCSVFile(QTextStream &outStream);
    void setRoundSelectColor(QColor color);
    QString getJournalFileName(QString type, QString extension);
    void roundSelectionIsInvalid(QString message = QString());
    QString getRankingTitle();

private slots:
    void checkTitle(QString title);
    void checkExportPossible();
    void checkRoundSelection(QString range);
    void setExportType(bool custom);

private: // Variables
    Database *m_db;
    RankingPage *m_rankingPage;
    QCheckBox *m_exportTitle;
    QLineEdit *m_titleEdit;
    QGroupBox *m_selectDataBox;
    QCheckBox *m_exportHeadlines;
    QCheckBox *m_exportSubHeadlines;
    QGroupBox *m_exportBox;
    QGroupBox *m_formatBox;
    QCheckBox *m_exportGenericData;
    QCheckBox *m_exportRanking;
    QCheckBox *m_exportRoundResults;
    QCheckBox *m_displayBoogers;
    QLineEdit *m_roundSelect;
    QColor m_defaultTextColor;
    QList<int> m_selectedRounds;
    QRadioButton *m_exportHTML;
    QRadioButton *m_exportCSV;
    QCheckBox *m_openAfterExport;
    QLabel *m_roundSelectLabel;
    QString m_dateFormat;
    QString m_timeFormat;
    bool m_roundSelectionIsRed = false;
    QLabel *m_errorLabel;
    QDialogButtonBox *m_buttonBox;
    QCheckBox *m_closeAfterExport;

};

#endif // EXPORTDIALOG_H
