/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

// Qt includes
#include <QMainWindow>
#include <QMap>

// Local classes
class Database;
class PlayersPage;
class ScorePage;
class RankingPage;

// Qt classes
class QTabWidget;
class QLabel;
class QAction;
class QDockWidget;
class QWidget;
class QPushButton;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow();
    QString resourcePath(QString fileName);

public slots:
    void updateStatus(QString message);
    void settingsSaved();
    void setScoreTabEnabled(bool state);
    void tournamentStarted();
    void loadTournament(QString dbToOpen = QString());
    void closeTournament();

protected:
    void resizeEvent(QResizeEvent *event);

private: // Functions
    void databaseChanged();
    void setPlayersTabName();
    void checkEnableRankingPage();
    void formatDockWidget(QDockWidget *dock);
    void attachDocks(Qt::DockWidgetArea area);
    void updateDatabase(QString dbFileName, int dbVersion);
    void dbReset();

private slots:
    void startNewTournament();
    void triggerLoadTournament();
    void quit();
    void showHandbook();
    void showAboutWindow();
    void showExportDialog();
    void showStopWatch();
    void showTournamentInfo();
    void exportPlayersList();
    void arrangeTabified();
    void arrangeHorizontally();
    void arrangeVertically();
    void arrangeOwnWindow();
    void resetDatabase();
    void importPlayersList();

private: // Variables
    Database *m_db;
    QDockWidget *m_playersDock;
    PlayersPage *m_playersPage;
    QDockWidget *m_scoreDock;
    ScorePage *m_scorePage;
    QDockWidget *m_rankingDock;
    RankingPage *m_rankingPage;
    QAction *m_exportAction;
    QAction *m_tournamentInfoAction;
    QWidget *m_centralWidget;
    QStringList m_possibleDataLocations;
    QMap<QString, QString> m_resourcePath;
    QAction *m_closeTournamentAction;
    QAction *m_exportPlayersListAction;
    QAction *m_resetDatabaseAction;
    QAction *m_importPlayersListAction;
    QString m_importPlayersListString;
    QString m_importPlayersListActionName;

};

#endif // MAINWINDOW_H
