/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLAYERSPAGE_H
#define PLAYERSPAGE_H

// Qt includes
#include <QWidget>

// Qt classes
class QGroupBox;
class QLabel;
class QLineEdit;
class QPushButton;
class QTableWidget;
class QMenu;
class QAction;
class QWidgetAction;

// Local classes
class Database;
class SearchWidget;

class PlayersPage : public QWidget
{
    Q_OBJECT

public:
    explicit PlayersPage(QWidget *parent, Database *db);
    void setPlayersNameFocus();
    void reload();
    void reset();

public slots:
    void scoreChanged();

signals:
    void statusUpdate(QString message);
    void tournamentCanBeStarted(bool state);
    void playersListChanged();
    void enableExport(bool enable);

private slots:
    void playersNameChanged(QString name);
    void registerPlayers();
    void cacheOriginalName();
    void editEntered();
    void setPlayersName(QString name);
    void showContextMenu(QPoint point);
    void editPlayers();
    void deletePlayers();
    void updateSearch(QString searchText);

private: // Variables
    Database *m_db;
    QGroupBox *m_newPlayersBox;
    QLabel *m_nameLabel;
    QLineEdit *m_playersName;
    QPushButton *m_registerButton;
    QGroupBox *m_playersBox;
    QTableWidget *m_playersList;
    QMenu *m_contextMenu;
    QLabel *m_menuTitle;
    QWidgetAction *m_menuTitleAction;
    QAction *m_editAction;
    QAction *m_deleteAction;
    QLabel *m_stateLabel;
    QString m_originalPlayersName;
    SearchWidget *m_searchWidget;
    QLabel *m_separatorLabel;
    QLabel *m_isSearchLabel;

};

#endif // PLAYERSPAGE_H
