/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef RANKINGPAGE_H
#define RANKINGPAGE_H

// Qt includes
#include <QWidget>
#include <QMap>

// Qt classes
class QGroupBox;
class QLabel;
class QTableWidget;
class QCheckBox;
class QComboBox;

// Local classes
class Database;
class SearchWidget;

class RankingPage : public QWidget
{
    Q_OBJECT
    friend class ExportDialog;

public:
    explicit RankingPage(QWidget *parent, Database *db);

signals:
    void statusUpdate(QString message);
    void playersListChanged();
    void scoreChanged();
    void enableExport(bool state);

public slots:
    void dataChanged();

private slots:
    void updateSearch(QString searchText);
    void toggleOpponentGoals();
    void showRankingUpToRound(int round);

private: // Functions
    void reload(int upToRound);

private: // Variables
    Database *m_db;
    QGroupBox *m_rankingBox;
    QLabel *m_interimLabel;
    QTableWidget *m_ranking;
    int m_allRounds;
    QCheckBox *m_regardOpponentGoals;
    SearchWidget *m_searchWidget;
    QLabel *m_isSearchLabel;
    QComboBox *m_upToRound;
    QMap<int, bool> m_roundsState;
    QLabel *m_upToRoundLabel;
    QLabel *m_multipleRanks;

};

#endif // RANKINGPAGE_H
